{% load admin_modify %}
{% if inline_admin_form.form.non_field_errors %}
    <tr class="row-form-errors group inline-tabular">
        <td colspan="{{ inline_admin_form|cell_count }}">
            {% include "unfold/helpers/messages/error.html" with errors=inline_admin_form.form.non_field_errors %}
        </td>
    </tr>
{% endif %}
