{% load i18n %}

<thead class="hidden lg:table-header-group">
    <tr>
        {% for field in inline_admin_formset.fields %}
            {% if not field.widget.is_hidden %}
                <th class="column-{{ field.name }}{% if field.required %} required{% endif %} align-middle border-b border-base-200 dark:border-base-800 font-semibold px-1.5 first:pl-3 last:pr-3 py-2 text-left text-font-important-light text-sm whitespace-nowrap dark:text-font-important-dark {% if inline_admin_formset.opts.ordering_field and field.name == inline_admin_formset.opts.ordering_field and inline_admin_formset.opts.hide_ordering_field %}hidden{% endif %}">
                    <span class="flex flex-row items-center">
                        {{ field.label|capfirst }}

                        {% if field.help_text %}
                            <span class="cursor-help material-symbols-outlined ml-2 text-base-400 dark:text-base-500" title="{{ field.help_text|striptags }}">help</span>
                        {% endif %}
                    </span>
                </th>
            {% endif %}
        {% endfor %}

        {% if inline_admin_formset.formset.can_delete and inline_admin_formset.has_delete_permission %}
            <th class="align-middle border-b border-base-200 dark:border-base-800 font-semibold px-3 py-2 text-left text-font-important-light text-sm whitespace-nowrap lg:w-px dark:text-font-important-dark">
                {% translate "Delete?" %}
            </th>
        {% endif %}
    </tr>
</thead>
