<div class="flex flex-row justify-center items-center gap-4 my-4">
    {% if title %}
        <span class="bg-base-200 grow h-px"></span>

        {% if title %}
            <span>
                {{ title }}
            </span>
        {% endif %}
    {% endif %}

    <span class="bg-base-200 grow h-px"></span>
</div>
